==> jc-1.4.0.tar.gz: scm/AutoInit.h <==
// class scm.AutoInit

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2cdc57fa2bb9f604 scm_AutoInit

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_AutoInit_H_
#define _JC_scm_AutoInit_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_scm_Env$object;

// Typedefs
typedef struct _jc_scm_AutoInit$sub_refs	_jc_scm_AutoInit$sub_refs;
typedef struct _jc_scm_AutoInit$sub_nonrefs	_jc_scm_AutoInit$sub_nonrefs;
typedef struct _jc_scm_AutoInit$refs	_jc_scm_AutoInit$refs;
typedef struct _jc_scm_AutoInit$nonrefs	_jc_scm_AutoInit$nonrefs;
typedef struct _jc_scm_AutoInit$object	_jc_scm_AutoInit$object;

typedef const struct _jc_scm_AutoInit$vmethods	_jc_scm_AutoInit$vmethods;
typedef const struct _jc_scm_AutoInit$vtable	_jc_scm_AutoInit$vtable;
typedef const struct _jc_scm_AutoInit$vtype	_jc_scm_AutoInit$vtype;

// Constructors
extern void _jc_scm_AutoInit$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_AutoInit$object *);

// Static methods
extern void _jc_scm_AutoInit$method$fillit$2172260a1171fed5(_jc_env *, struct _jc_scm_Env$object *);

// Virtual methods structure
struct _jc_scm_AutoInit$vmethods {
};

// Vtable
struct _jc_scm_AutoInit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_AutoInit$vmethods	scm_AutoInit;
};

// Vtype
struct _jc_scm_AutoInit$vtype {
	_jc_type			type;
	_jc_scm_AutoInit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_AutoInit$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_AutoInit$refs {
    _jc_scm_AutoInit$sub_refs	scm_AutoInit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_AutoInit$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_AutoInit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_AutoInit$sub_nonrefs	scm_AutoInit;
};

// Object instance structure
struct _jc_scm_AutoInit$object {
	_jc_scm_AutoInit$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_AutoInit$vtype	*vtype;
	_jc_scm_AutoInit$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_AutoInit$vtype _jc_scm_AutoInit$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_AutoInit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_AutoInit$class_object;

#endif	/* _JC_scm_AutoInit_H_ */

==> jc-1.4.6.tar.gz: scm/AutoInit.h <==
// class scm.AutoInit

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2cdc57fa2bb9f604 scm_AutoInit

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_AutoInit_H_
#define _JC_scm_AutoInit_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_scm_Env$object;

// Typedefs
typedef struct _jc_scm_AutoInit$sub_refs	_jc_scm_AutoInit$sub_refs;
typedef struct _jc_scm_AutoInit$sub_nonrefs	_jc_scm_AutoInit$sub_nonrefs;
typedef struct _jc_scm_AutoInit$refs	_jc_scm_AutoInit$refs;
typedef struct _jc_scm_AutoInit$nonrefs	_jc_scm_AutoInit$nonrefs;
typedef struct _jc_scm_AutoInit$object	_jc_scm_AutoInit$object;

typedef const struct _jc_scm_AutoInit$vmethods	_jc_scm_AutoInit$vmethods;
typedef const struct _jc_scm_AutoInit$vtable	_jc_scm_AutoInit$vtable;
typedef const struct _jc_scm_AutoInit$vtype	_jc_scm_AutoInit$vtype;

// Constructors
extern void _jc_scm_AutoInit$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_scm_AutoInit$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_scm_AutoInit$method$fillit$2172260a1171fed5(_jc_env *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_scm_AutoInit$vmethods {
};

// Vtable
struct _jc_scm_AutoInit$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_AutoInit$vmethods	scm_AutoInit;
};

// Vtype
struct _jc_scm_AutoInit$vtype {
	_jc_type			type;
	_jc_scm_AutoInit$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_AutoInit$sub_refs {
};

// Reference instance fields (object)
struct _jc_scm_AutoInit$refs {
    _jc_scm_AutoInit$sub_refs	scm_AutoInit;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_AutoInit$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_AutoInit$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_AutoInit$sub_nonrefs	scm_AutoInit;
};

// Object instance structure
struct _jc_scm_AutoInit$object {
	_jc_scm_AutoInit$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_AutoInit$vtype	*vtype;
	_jc_scm_AutoInit$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_AutoInit$vtype _jc_scm_AutoInit$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_AutoInit, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_AutoInit$class_object;

#endif	/* _JC_scm_AutoInit_H_ */
